Range-v3: ranges::v3::raw_storage_iterator< O, Val > Struct Template Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Types | Public Member Functions | List of all members
ranges::v3::raw_storage_iterator< O, Val > Struct Template Reference
Utility

## Public Types
using | difference_type = difference_type_t< O >

## Public Member Functions
O | base () const
raw_storage_iterator & | operator* () noexcept
raw_storage_iterator & | operator++ ()
void | operator++ (int)
raw_storage_iterator | operator++ (int)
raw_storage_iterator & | operator= (Val const &val)
raw_storage_iterator & | operator= (Val &&val)
| raw_storage_iterator (O out)

## Member Function Documentation

## ◆ operator++() [1/2]

template<typename O, typename Val>

void ranges::v3::raw_storage_iterator< O, Val >::operator++ | ( | int |  | ) |

Precondition
  !ForwardIterator<O>()

## ◆ operator++() [2/2]

template<typename O, typename Val>

raw_storage_iterator ranges::v3::raw_storage_iterator< O, Val >::operator++ | ( | int |  | ) |

Precondition
  ForwardIterator<O>()

## ◆ operator=() [1/2]

template<typename O, typename Val>

raw_storage_iterator& ranges::v3::raw_storage_iterator< O, Val >::operator= | ( | Val const & | val | ) |

Precondition
  CopyConstructible<Val>()

## ◆ operator=() [2/2]

template<typename O, typename Val>

raw_storage_iterator& ranges::v3::raw_storage_iterator< O, Val >::operator= | ( | Val && | val | ) |

Precondition
  MoveConstructible<Val>()